{
  const setNativeValue = (element, value) => {
    let lastValue = element.value;
    element.value = value;
    //@ts-ignore
    let event = new Event("input", { target: element, bubbles: true });
    // React 15
    //@ts-ignore
    event.simulated = true;
    // React 16
    let tracker = element._valueTracker;
    if (tracker) {
      tracker.setValue(lastValue);
    }
    element.dispatchEvent(event);
    element.dispatchEvent(new KeyboardEvent("keydown", { key: "enter" }));
    element.dispatchEvent(new KeyboardEvent("keypress", { key: "enter" }));
    element.dispatchEvent(new KeyboardEvent("keyup", { key: "enter" }));
  };

  async function waitForSelector(selector, { Qinterval = 200, hidden = false } = {}) {
    return new Promise((r) => {
      const interval = setInterval(() => {
        const ele = document.querySelector(selector);
        if (ele && !hidden) {
          clearInterval(interval);
          r(ele);
        } else if (!ele && hidden) {
          clearInterval(interval);
          r(false);
        }
      }, Qinterval);
    });
  }

  (async () => {
    try {
      const { runData } = await chrome.storage.local.get();
      const { prompt, id } = runData;

      const promptTextArea = document.querySelector("#prompt-textarea");
      setNativeValue(promptTextArea, prompt);
      await new Promise((r) => {
        const interval = setInterval(() => {
          const submit = document.querySelector("textarea").parentElement.querySelector("button");
          if (!submit.disabled) {
            clearInterval(interval);
            submit.click();
            r(true);
          }
        }, 100);
      });

      console.log("Waiting stream start");
      await waitForSelector(".result-streaming");
      console.log("Waiting stream finish");
      await waitForSelector(".result-streaming", { hidden: true });
      console.log("Stream finished");
      const chatEntries = Array.from(document.querySelectorAll(".text-base"));
      const answer = chatEntries[chatEntries.length - 1].querySelector(".markdown").outerHTML;
      const chatPrompt = chatEntries[chatEntries.length - 2].innerText;
      const result = { id, answer, chatPrompt, createdAt: new Date().toString() };
      let { history } = await chrome.storage.local.get();
      if (history == undefined) history = [];
      await chrome.storage.local.set({
        history: [...history, result],
      });
    } catch (err) {
      console.log(err);
    }
  })();
}
